@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: shakespeare
-version: 2.0.7
-id: shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
-key: shake_5C0sDlUm7TL3jw8eYGgvyw
+version: 2.0.8
+id: shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
+key: shake_1vghqhLLSePE0tznKG19vt
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -16,7 +16,7 @@ description:
     .
     Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
     .
-    Packages that use this: shakespeare-js, shakespeare-css, shakespeare-text, hamlet, and xml-hamlet
+    Packages that use this: xml-hamlet
     .
     Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
 category: Web, Yesod
@@ -30,28 +30,28 @@ exposed-modules:
 hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                 Text.IndentToBrace Text.CssCommon
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
-library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
-data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.7
-hs-libraries: HSshakespeare-2.0.7-5C0sDlUm7TL3jw8eYGgvyw
+import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8
+library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.8
+data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.8
+hs-libraries: HSshakespeare-2.0.8-1vghqhLLSePE0tznKG19vt
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
-    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
+    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
-    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
+    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
-    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
+    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
 haddock-html: /usr/share/doc/haskell-shakespeare/html
